/************************************************************************************************************************************/
/** @file		main.c
 * 	@brief		This is the Jmr Template Project intended for starting use on all future projects
 *
 *  @target		TI Tiva TM4C1294NCPDT - Silicon Revision 2
 *	@board		all
 *
 * 	@author		Justin Reina, Firmware Engineer, Misc. Company
 * 	@created	10/25/16
 * 	@last rev	10/25/16
 *
 *  @section	Reference
 *  			- TI ASM Ref:				 ARM Assembly Language Tools v15.12.0.LTS User's Guide - spnu1180.pdf
 *  			- memory location placement: http://processors.wiki.ti.com/index.php/Placing_Variables_in_Specific_Memory_Location_-_MSP430
 *  			- macro args: 				 https://gcc.gnu.org/onlinedocs/cpp/Macro-Arguments.html
 *
 * 	@section	Opens
 * 			none current
 *
 * 	@section	Legal Disclaimer
 * 			All contents of this source file and/or any other Misc. Product related source files are the explicit property of
 * 			Misc. Company. Do not distribute. Do not copy.
 */
/************************************************************************************************************************************/
#include "globals.h"

#pragma location=0x00000600
volatile const uint32_t flash_var = 0x12345678;

#pragma location = 0x20000220
volatile uint32_t ram_var = 0x87654321;


/************************************************************************************************************************************/
/**	@fcn		int main(void)
 *  @brief		x
 */
/************************************************************************************************************************************/
int main(void) {

	//Example Code for Dissassembly Review
	ram_var = flash_var;
	ram_var = 0xF020F111;

	//	C inline
	asm(" nop");

	asm(" movw       r0, #0x0600");											//r0 =  &flash_var
	asm(" movt       r0, #0x0000");											//""
	asm(" ldr        r0, [r0]");											//r0 = *&flash_var
	asm(" movw       r1, #0x0220");											//r1 =  &ram_var
	asm(" movt       r1, #0x2000");											//""
	asm(" str        r0, [r1]");											//ram_var = r0 (the value of flash_var!)

	asm(" movw       r1, #0x0220");											//r1_lwr = &ram_var
	asm(" movt       r1, #0x2000");											//r1_top = &ram_var
	asm(" movw       r0, #0xeedd");											//r0_lwr = value_lwrU16
	asm(" movt       r0, #0xff44");											//r0_top = value_topU16
	asm(" str        r0, [r1]");											//ram_var = value_U32

	// #defines
	_nop();

	// Asm function-file calls
	asmFcn1();
	asmFcn2();

	//Asm variable usage
	ram_var   = asmFlashVal;
	asmRAMVal = 0xE234;

	return EXIT_SUCCESS;
}

